==> james-project-3.7.6-source-release.zip: james-project/server/protocols/jmap-rfc-8621/src/main/scala/org/apache/james/jmap/mail/BlobId.scala <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.jmap.mail

import eu.timepit.refined.refineV
import org.apache.james.jmap.core.Id.{Id, IdConstraint}
import org.apache.james.mailbox.model.MessageId

import scala.util.{Failure, Success, Try}

object BlobId {
  def of(string: String): Try[BlobId] = refineV[IdConstraint](string) match {
      case scala.Right(value) => Success(BlobId(value))
      case Left(e) => Failure(new IllegalArgumentException(e))
    }
  def of(messageId: MessageId): Try[BlobId] = of(messageId.serialize())
  def of(messageId: MessageId, partId: PartId): Try[BlobId] = of(s"${messageId.serialize()}_${partId.serialize}")
}

case class BlobId(value: Id)

==> james-project-3.9.0-source-release.zip: james-project/server/protocols/jmap-rfc-8621/src/main/scala/org/apache/james/jmap/mail/BlobId.scala <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.jmap.mail

import eu.timepit.refined.refineV
import org.apache.james.jmap.core.Id.{Id, IdConstraint}
import org.apache.james.mailbox.model.MessageId

import scala.util.{Failure, Success, Try}

object BlobId {
  def of(string: String): Try[BlobId] = refineV[IdConstraint](string) match {
      case scala.Right(value) => Success(BlobId(value))
      case Left(e) => Failure(new IllegalArgumentException(e))
    }
  def of(messageId: MessageId): Try[BlobId] = of(messageId.serialize())
  def of(messageId: BlobId, partId: PartId): Try[BlobId] = of(s"${messageId.value.value}_${partId.serialize}")
}

case class BlobId(value: Id)
